@@ -23,17 +23,16 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-           '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
-           '-fno-semantic-interposition -march=armv8-a -O3 -pipe '
-           '-fstack-protector-strong -fno-plt -march=armv8-a -O3 -pipe '
-           '-fstack-protector-strong -fno-plt',
+           '-march=armv8-a -O3 -pipe -fno-plt -fno-semantic-interposition '
+           '-march=armv8-a -O3 -pipe -fno-plt -march=armv8-a -O3 -pipe '
+           '-fno-plt',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-march=armv8-a -O3 -pipe -fstack-protector-strong '
-                     '-fno-plt -fno-semantic-interposition',
+ 'CONFIGURE_CFLAGS': '-march=armv8-a -O3 -pipe -fno-plt '
+                     '-fno-semantic-interposition',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
@@ -47,8 +46,8 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-dbmliborder=gdbm:ndbm' '--with-system-ffi' "
                 "'--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
-                "'CFLAGS=-march=armv8-a -O3 -pipe -fstack-protector-strong "
-                "-fno-plt -fno-semantic-interposition' "
+                "'CFLAGS=-march=armv8-a -O3 -pipe -fno-plt "
+                "-fno-semantic-interposition' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now "
                 "-fno-semantic-interposition' 'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
@@ -635,33 +634,29 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O3 -Wall -march=armv8-a -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt '
-                             '-fno-semantic-interposition -march=armv8-a -O3 '
-                             '-pipe -fstack-protector-strong -fno-plt '
-                             '-march=armv8-a -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt -std=c99 '
-                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                             '-fno-plt -fno-semantic-interposition '
+                             '-march=armv8-a -O3 -pipe -fno-plt -march=armv8-a '
+                             '-O3 -pipe -fno-plt -std=c99 -Wextra '
+                             '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration  '
                              '-I./Include/internal -I. -I./Include '
                              '-D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2 -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-              '-march=armv8-a -O3 -pipe -fstack-protector-strong -fno-plt '
-              '-fno-semantic-interposition -march=armv8-a -O3 -pipe '
-              '-fstack-protector-strong -fno-plt -march=armv8-a -O3 -pipe '
-              '-fstack-protector-strong -fno-plt',
+              '-march=armv8-a -O3 -pipe -fno-plt -fno-semantic-interposition '
+              '-march=armv8-a -O3 -pipe -fno-plt -march=armv8-a -O3 -pipe '
+              '-fno-plt',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration  '
                      '-I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
-                   '-Wall -march=armv8-a -O3 -pipe -fstack-protector-strong '
-                   '-fno-plt -fno-semantic-interposition -march=armv8-a -O3 '
-                   '-pipe -fstack-protector-strong -fno-plt -march=armv8-a -O3 '
-                   '-pipe -fstack-protector-strong -fno-plt -std=c99 -Wextra '
-                   '-Wno-unused-result -Wno-unused-parameter '
+                   '-Wall -march=armv8-a -O3 -pipe -fno-plt '
+                   '-fno-semantic-interposition -march=armv8-a -O3 -pipe '
+                   '-fno-plt -march=armv8-a -O3 -pipe -fno-plt -std=c99 '
+                   '-Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration  '
                    '-I./Include/internal -I. -I./Include -D_FORTIFY_SOURCE=2 '
@@ -678,11 +673,9 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
-                        '-O3 -Wall -march=armv8-a -O3 -pipe '
-                        '-fstack-protector-strong -fno-plt '
+                        '-O3 -Wall -march=armv8-a -O3 -pipe -fno-plt '
                         '-fno-semantic-interposition -march=armv8-a -O3 -pipe '
-                        '-fstack-protector-strong -fno-plt -march=armv8-a -O3 '
-                        '-pipe -fstack-protector-strong -fno-plt -std=c99 '
+                        '-fno-plt -march=armv8-a -O3 -pipe -fno-plt -std=c99 '
                         '-Wextra -Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration  '
